@@ -153,7 +153,7 @@ def convert_to_timezone_naive(time_to_freeze):
     Converts a potentially timezone-aware datetime to be a naive UTC datetime
     """
     if time_to_freeze.tzinfo:
-        time_to_freeze += time_to_freeze.utcoffset()
+        time_to_freeze -= time_to_freeze.utcoffset()
         time_to_freeze =  time_to_freeze.replace(tzinfo=None)
     return time_to_freeze
 
@@ -203,6 +203,10 @@ class _freeze_time(object):
             if not hasattr(attr_value, "__call__"):
                 continue
 
+            # Check if this is a classmethod. If so, skip patching
+            if inspect.ismethod(attr_value) and attr_value.__self__ is klass:
+                continue
+
             try:
                 setattr(klass, attr, self(attr_value))
             except TypeError:
