@@ -230,6 +230,10 @@ class TestUnitTestClassDecorator(unittest.TestCase):
     def setUp(self):
         self.assertEqual(datetime.date(2013,4,9), datetime.date.today())
 
+    @classmethod
+    def setUpClass(cls):
+        datetime.date(2013,4,9).shouldnt.equal(datetime.date.today())
+
     def test_class_decorator_works_on_unittest(self):
         self.assertEqual(datetime.date(2013,4,9), datetime.date.today())
 
@@ -295,4 +299,4 @@ def test_freeze_with_timezone_aware_datetime_in_non_utc():
     """
     utc_now = datetime.datetime.utcnow()
     assert utc_now.tzinfo == None
-    assert utc_now == datetime.datetime(1969, 12, 31, 20)
+    assert utc_now == datetime.datetime(1970, 1, 1, 4)
